#
# spec file for package materia-suse-gtk-theme
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name                   materia-theme
%define lvariant                suse
%define variant                 SUSE

# SUSE color palette:
# https://brand.suse.com/brand-system/color-palette

# Jungle
%define AccentColorLight        30BA78

# Seafoam
%define AccentColorDark         7AD4AA

# Coral
%define GnomeShellCloseLight    FF6A52

# Salmon
%define GnomeShellCloseDark     FF8E77


Name:           materia-%{lvariant}-gtk-theme
Version:        20191017
Release:        lp152.2.1
Summary:        A Material Design theme for GNOME/GTK+ based desktop environments
License:        GPL-2.0-only
Group:          System/GUI/Other
URL:            https://github.com/nana-4/materia-theme
Source:         https://github.com/nana-4/%{_name}/archive/v%{version}.tar.gz#/%{_name}-%{version}.tar.gz
BuildRequires:  bc
BuildRequires:  fdupes
# From Materia Kolorizer
BuildRequires:  sassc, inkscape, optipng
Requires:       gnome-themes-extras
Recommends:     gtk2-engine-murrine
BuildArch:      noarch

%description
Materia (formerly Flat-Plat) is a Material Design theme for GNOME/GTK+ based desktop environments.
It supports GTK+ 3, GTK+ 2, GNOME Shell, Budgie, Cinnamon, MATE, Unity, LightDM, GDM, Chrome theme, etc.

This package provides a variation of the Materia GTK theme customized with %{variant} colors.

%prep
%autosetup -n %{_name}-%{version}

%build
# Based on Materia Kolorizer @ 7c61bc82
# https://github.com/DarthWound/materia-kolorizer
# https://github.com/DarthWound/materia-kolorizer/blob/7c61bc824724e94a3713cfb02759046e0b4f31d7/materia-kolorizer.sh

sed -i "s/1A73E8/%{AccentColorLight}/gI" src/_sass/_colors.scss
sed -i "s/1A73E8/%{AccentColorLight}/gI" src/gnome-shell/assets/*.svg
sed -i "s/1A73E8/%{AccentColorLight}/gI" src/gtk/assets.svg
sed -i "s/1A73E8/%{AccentColorLight}/gI" src/gtk-2.0/assets.svg
sed -i "s/1A73E8/%{AccentColorLight}/gI" src/gtk-2.0/gtkrc{,-light}
sed -i "s/1A73E8/%{AccentColorLight}/gI" src/cinnamon/*.scss
sed -i "s/1A73E8/%{AccentColorLight}/gI" src/cinnamon/assets/*.svg
sed -i "s/1A73E8/%{AccentColorLight}/gI" src/xfwm4/assets/*.svg
sed -i "s/1A73E8/%{AccentColorLight}/gI" src/xfwm4/assets-light/*.svg

sed -i "s/8AB4F8/%{AccentColorDark}/gI" src/_sass/_colors.scss
sed -i "s/8AB4F8/%{AccentColorDark}/gI" src/gnome-shell/assets-dark/*.svg
sed -i "s/8AB4F8/%{AccentColorDark}/gI" src/gtk/assets.svg
sed -i "s/8AB4F8/%{AccentColorDark}/gI" src/gtk-2.0/assets-dark.svg
sed -i "s/8AB4F8/%{AccentColorDark}/gI" src/gtk-2.0/gtkrc-dark
sed -i "s/8AB4F8/%{AccentColorDark}/gI" src/cinnamon/*.scss
sed -i "s/8AB4F8/%{AccentColorDark}/gI" src/cinnamon/assets/*.svg
sed -i "s/8AB4F8/%{AccentColorDark}/gI" src/xfwm4/assets/*.svg
sed -i "s/8AB4F8/%{AccentColorDark}/gI" src/xfwm4/assets-light/*.svg

sed -i "s/D93025/%{GnomeShellCloseLight}/gI" src/gnome-shell/assets/window-close{,-active}.svg
sed -i "s/F28B82/%{GnomeShellCloseDark}/gI" src/gnome-shell/assets-dark/window-close{,-active}.svg

sleep 2s

./parse-sass.sh
./render-assets.sh

%install
./install.sh --name "Materia-%{variant}" --dest %{buildroot}%{_datadir}/themes

%fdupes %{buildroot}

#fix permissions
find %{buildroot}/%{_datadir}/themes -type f -exec chmod -x {} \;
#remove duplicate COPYING files
find %{buildroot}%{_datadir}/themes -name COPYING -delete

%files
%license COPYING
%doc README.md
%{_datadir}/themes/*

%changelog
* Mon Mar  9 2020 Antônio Vinícius Menezes Medeiros Medeiros <linuxkamarada@gmail.com>
- First packaging of the Materia-openSUSE theme, based on Materia and Materia Kolorizer
* Thu Mar  5 2020 Antônio Vinícius Menezes Medeiros Medeiros <linuxkamarada@gmail.com> - 20191017
- Update to version 20191017
  * Add support for GNOME Shell 3.34 (actually, on a previous version, 20190912)
  * Follow the upstream GNOME 3.34.1 changes
  * Fix broken header bar in gnome-tweaks 3.34
  * Other various minor fixes and improvements
* Fri Mar 15 2019 Matthias Eliasson <elimat@opensuse.org>
- Update to version 20190315
  * Add support for GNOME 3.32
  * Various improvements of source Sass code
* Sat Feb  2 2019 Matthias Eliasson <matthias.eliasson@gmail.com>
- Update to version 20190201
  * Added support for Plank
  * Added support for Xfce >=4.13
  * Dropped support for Budgie <10.4
  * Dropped (teal) secondary color
  * Changed entry style (as per refreshed Material Design Guidelines)
  * Changed combo button style (as per refreshed Material Design Guidelines)
  * Changed selected state style (as per refreshed Material Design Guidelines)
  * Changed sidebar style (as per refreshed Material Design Guidelines)
  * Changed headerbar's separator style
  * Tweaked button colors
  * Changed progress bar background-color to neutral gray
  * Changed disabled check/radio colors
  * Dropped excessive check/radio animations
  * budgie: Changed raven's tab bar colors
  * gnome-shell: Fixed .workspace-thumbnail-indicator position
  * gnome-shell: Tweaked transitions
  * Applied various style improvements for Budgie and Cinnamon
* Tue Dec 11 2018 Matthias Eliasson <matthias.eliasson@gmail.com>
- Fix typo in source url
* Sun Dec  2 2018 Matthias Eliasson <matthias.eliasson@gmail.com>
- Initial package of version 20181125
